<?php
namespace Pinpoint\DeliveryDate\Controller\Adminhtml\Disallowed;

use Magento\Backend\App\Action;

/**
 * Class Delete
 * @package Pinpoint\DeliveryDate\Controller\Adminhtml\Disallowed
 */
class Delete extends \Magento\Backend\App\Action
{
    /**
     *
     */
    const ADMIN_RESOURCE = 'Pinpoint_DeliveryDate::delivery_dates';

    /**
     * @var \Pinpoint\DeliveryDate\Model\DisallowedDateRepository
     */
    protected $disallowedDateRepository;

    /**
     * Delete constructor.
     * @param Action\Context $context
     * @param \Pinpoint\DeliveryDate\Model\DisallowedDateRepository $disallowedDate
     */
    public function __construct(
        Action\Context $context,
        \Pinpoint\DeliveryDate\Model\DisallowedDateRepository $disallowedDate
    ) {
        $this->disallowedDateRepository = $disallowedDate;
        parent::__construct($context);
    }

    /**
     * Check the permission to run it
     *
     * @return boolean
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_DeliveryDate::delivery_dates');
    }

    /**
     * @return \Magento\Backend\Model\View\Result\Redirect
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {
                $this->disallowedDate->deleteById($id);

                $this->messageManager->addSuccess(__('You have deleted the date.'));
                return $resultRedirect->setPath('*/*/list');
            } catch (\Exception $e) {
                $this->messageManager->addError($e->getMessage());
                return $resultRedirect->setPath('*/*/edit', ['id' => $id]);
            }
        }

        $this->messageManager->addError(__('We can not find a date to delete.'));
        return $resultRedirect->setPath('*/*/list');
    }    
    
}
